@@ -146,7 +146,7 @@ class TEI:
     """
 
     @staticmethod
-    def parse(stream, sentences=False, figures=False):
+    def parse(stream, figures=False):
         """
         Parses a TEI XML datastream and returns a processed article.
 
@@ -158,6 +158,7 @@ class TEI:
         from .models import Article
 
         soup = BeautifulSoup(stream, "lxml")
+        sentences = soup.find("s") is not None
         title = soup.title.text
         art = Article(identifier=None, title=title)
         source = soup.find("sourcedesc")
@@ -424,7 +425,7 @@ class TEI:
                 if "type" in el.attrs:
                     ref.type = el["type"]
                 if "target" in el.attrs:
-                    ref.type = el["target"]
+                    ref.target = el["target"]
                 refs.append(ref)
             else:
                 text += str(el)
